@@ -378,7 +378,29 @@ START_TEST(test_openbsd)
 }
 END_TEST
 
+START_TEST(test_opensuse)
+{
+    test_one("opensuse");
+}
+END_TEST
 
+START_TEST(test_centos)
+{
+    test_one("centos");
+}
+END_TEST
+
+START_TEST(test_gnome)
+{
+    test_one("gnome");
+}
+END_TEST
+
+START_TEST(test_altlinux)
+{
+    test_one("altlinux");
+}
+END_TEST
 
 static Suite *
 list_suite(void)
@@ -393,6 +415,10 @@ list_suite(void)
     tcase_add_test(tc, test_debian);
     tcase_add_test(tc, test_windows);
     tcase_add_test(tc, test_openbsd);
+    tcase_add_test(tc, test_opensuse);
+    tcase_add_test(tc, test_centos);
+    tcase_add_test(tc, test_gnome);
+    tcase_add_test(tc, test_altlinux);
     suite_add_tcase(s, tc);
     return s;
 }
